pub struct FieldObject {
pub section: Option<SectionID>,
pub purpose: Option<String>,
pub type: Option<String>,
pub value: Option<String>,
pub generate: Option<bool>,
pub label: Option<String>,
}Expand description
This is a Field Object
Fields
section: Option<SectionID>An object containing the UUID of a section in the item.
purpose: Option<String>Use purpose for the username, password, and notes fields.
type: Option<String>Use `type’ for all other fields
value: Option<String>The value to save for the field. You can specify a generate field instead of value to create a password or other random information for the value.
generate: Option<bool>Generate a password and save in the value for the field. By default, the password is a 32-characters long, made up of letters, numbers, and symbols. To customize the password, include a recipe field.
label: Option<String>Some optional text